@@ -19,6 +19,11 @@ D578UVLimits::D578UVLimits(const std::initializer_list<std::pair<Frequency, Freq
   _callSignDBImplemented  = true;
   _numCallSignDBEntries   = 500000;
 
+  // Define limits for satellite config
+  _hasSatelliteConfig          = false;
+  _satelliteConfigImplemented  = false;
+  _numSatellites               = 0;
+
   /* Define limits for the general settings. */
   add("settings",
       new RadioLimitItem{
@@ -138,7 +143,7 @@ D578UVLimits::D578UVLimits(const std::initializer_list<std::pair<Frequency, Freq
   /* Define limits for scan lists. */
   add("scanlists",
       new RadioLimitList(
-        ScanList::staticMetaObject, 1, 250, new RadioLimitObject{
+        ScanList::staticMetaObject, 0, 250, new RadioLimitObject{
           { "name", new RadioLimitString(1, 16, RadioLimitString::ASCII) },
           { "primary", new RadioLimitObjRef(Channel::staticMetaObject, false) },
           { "secondary", new RadioLimitObjRef(Channel::staticMetaObject, true) },
@@ -152,11 +157,11 @@ D578UVLimits::D578UVLimits(const std::initializer_list<std::pair<Frequency, Freq
             { "name", new RadioLimitStringIgnored() },
             { "period", new RadioLimitUInt(0, 7650) },
             { "contact", new RadioLimitObjRef(DMRContact::staticMetaObject, false) },
-            { "revert", new RadioLimitObjRef(DMRChannel::staticMetaObject, true) } } },
+            { "revert", new RadioLimitObjRef({SelectedChannel::staticMetaObject, DMRChannel::staticMetaObject}, true) } } },
         { APRSSystem::staticMetaObject, 0, 1, new RadioLimitObject {
             { "name", new RadioLimitStringIgnored() },
             { "period", new RadioLimitUInt(0, 7650) },
-            { "revert", new RadioLimitObjRef(FMChannel::staticMetaObject, false) },
+            { "revert", new RadioLimitObjRef({SelectedChannel::staticMetaObject, FMChannel::staticMetaObject}, false) },
             { "icon", new RadioLimitEnum{} },
             { "message", new RadioLimitString(0, 60, RadioLimitString::ASCII) }
             ///@todo extend APRSSystem to expose other settings as properties.
