@@ -18,6 +18,11 @@ DM1701Limits::DM1701Limits(QObject *parent)
   _callSignDBImplemented  = true;
   _numCallSignDBEntries   = 122197;
 
+  // Define limits for satellite config
+  _hasSatelliteConfig          = false;
+  _satelliteConfigImplemented  = false;
+  _numSatellites               = 0;
+
   add("settings", new RadioLimitItem {
         { "introLine1", new RadioLimitString(-1, 10, RadioLimitString::Unicode) },
         { "introLine2", new RadioLimitString(-1, 10, RadioLimitString::Unicode) },
@@ -76,7 +81,7 @@ DM1701Limits::DM1701Limits(QObject *parent)
                                                                  {Frequency::fromMHz(400.), Frequency::fromMHz(480.)}})},
               {"power", new RadioLimitEnum{unsigned(Channel::Power::Low), unsigned(Channel::Power::High)}},
               {"timeout", new RadioLimitUInt(0, -1, std::numeric_limits<unsigned>::max())},
-              {"scanlist", new RadioLimitObjRef(ScanList::staticMetaObject)},
+              {"scanlist", new RadioLimitObjRef({ScanList::staticMetaObject})},
               {"vox", new RadioLimitUInt(0, 10, std::numeric_limits<unsigned>::max())},
               {"rxOnly", new RadioLimitBool()},
               {"openGD77", new RadioLimitIgnored(RadioLimitIssue::Hint)},
@@ -138,7 +143,7 @@ DM1701Limits::DM1701Limits(QObject *parent)
 
   /* Define limits for scan lists. */
   add("scanlists", new RadioLimitList(
-        ScanList::staticMetaObject, 1, 250, new RadioLimitObject{
+        ScanList::staticMetaObject, 0, 250, new RadioLimitObject{
           { "name", new RadioLimitString(1, 16, RadioLimitString::Unicode) },
           { "primary", new RadioLimitObjRef(Channel::staticMetaObject, true) },
           { "secondary", new RadioLimitObjRef(Channel::staticMetaObject, true) },
@@ -147,13 +152,13 @@ DM1701Limits::DM1701Limits(QObject *parent)
         }) );
 
   /* Define limits for positioning systems. */
-  add("positioning", new RadioLimitList(
-        GPSSystem::staticMetaObject, 0, 16, new RadioLimitObject {
+  add("positioning", new RadioLimitList({
+        { GPSSystem::staticMetaObject, 0, 16, new RadioLimitObject {
           { "name", new RadioLimitStringIgnored() },
           { "period", new RadioLimitUInt(0, 7650) },
           { "contact", new RadioLimitObjRef(DMRContact::staticMetaObject, false) },
-          { "revert", new RadioLimitObjRef(DMRChannel::staticMetaObject, true) }
-        } ) );
+          { "revert", new RadioLimitObjRef({SelectedChannel::staticMetaObject, DMRChannel::staticMetaObject}, true) } } },
+        { APRSSystem::staticMetaObject, 0, -1, new RadioLimitIgnored() } } ) );
 
   /* Check encryption keys. */
   add("commercial", new RadioLimitItem {
